/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.microkernel.jbi.messaging.routing.mock;

import java.util.List;
import java.util.Map;
import java.util.Properties;

import javax.jbi.JBIException;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;

import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.ow2.petals.clientserverapi.jbi.messaging.registry.exception.RegistryException;
import org.ow2.petals.jbi.descriptor.original.generated.LinkType;
import org.ow2.petals.microkernel.api.implementation.exception.MutableImplException;
import org.ow2.petals.microkernel.api.jbi.messaging.registry.EndpointRegistry;
import org.ow2.petals.microkernel.api.jbi.messaging.registry.RegistryListener;
import org.ow2.petals.microkernel.api.jbi.messaging.registry.exception.DynamicTopologyNotLockedByCurrentThreadException;
import org.ow2.petals.microkernel.api.jbi.messaging.registry.exception.DynamicTopologyNotLockedException;
import org.ow2.petals.microkernel.api.jbi.servicedesc.JBIServiceEndpointImpl;
import org.ow2.petals.topology.generated.Topology;
import org.w3c.dom.Document;

/**
 * Mock of the EndpointRegistry.
 * @author ddesjardins - EBM WebSourcing
 */
public class MockEndpointRegistry implements EndpointRegistry {

    public void deactivateEndpoint(ServiceEndpoint endpoint) {
    }

    public void deregisterInternalEndpoint(ServiceEndpoint endpoint) throws JBIException {
    }

    public void deregisterExternalEndpoint(ServiceEndpoint endpoint) {
    }

    public org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint getEndpoint(
            QName service,
            String name) {
        JBIServiceEndpointImpl ep = new JBIServiceEndpointImpl();
        ep.setServiceName(service);
        ep.setEndpointName(name);
        ep.getLocation().setComponentName("compo");
        ep.getLocation().setContainerName("0");
        ep.getLocation().setSubdomainName("subdomain");
        return ep;
    }

    public Document getEndpointDescriptorForEndpoint(ServiceEndpoint endpoint) {
        return null;
    }

    public ServiceEndpoint[] getInternalEndpointsForInterface(QName interfaceName) {
        JBIServiceEndpointImpl ep = new JBIServiceEndpointImpl();
        ep.setServiceName(new QName("service"));
        ep.setEndpointName("endpoint");
        ep.getLocation().setComponentName("compo");
        ep.getLocation().setContainerName("0");
        ep.getLocation().setSubdomainName("subdomain");
        ServiceEndpoint[] endpoints = new ServiceEndpoint[] { ep };
        return endpoints;
    }

    public ServiceEndpoint[] getInternalEndpointsForService(QName serviceName) {
        if (serviceName.equals(new QName("foo"))) {
            return new ServiceEndpoint[0];
        }
        // return new InternalEndpoint[] {
        // new InternalEndpoint(new QName("service"), "endpoint", "compo", "0",
        // "subdomain",
        // this),
        // new InternalEndpoint(new QName("servicename"), "endpoint1", "compo",
        // "0",
        // "subdomain", this) };

        return null;
    }

    public org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint[] getExternalEndpointsForInterface(
            QName interfaceName) {
        return null;
    }

    public org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint[] getExternalEndpointsForService(
            QName serviceName) {
        return null;
    }

    public void registerExternalEndpoint(ServiceEndpoint externalEndpoint) {
    }

    public org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint getInternalEndpoint(
            QName service,
            String name) {
        JBIServiceEndpointImpl ep = new JBIServiceEndpointImpl();
        ep.setServiceName(new QName("service"));
        ep.setEndpointName("endpoint");
        ep.getLocation().setComponentName("compo");
        ep.getLocation().setContainerName("0");
        ep.getLocation().setSubdomainName("subdomain");

        return ep;
    }

    public String getFcState() {
        return null;
    }

    public Object lookupFc(String arg0) throws NoSuchInterfaceException {
        return null;
    }

    public void bindFc(String arg0, Object arg1) throws NoSuchInterfaceException,
            IllegalBindingException, IllegalLifeCycleException {
    }

    public void unbindFc(String arg0) throws NoSuchInterfaceException, IllegalBindingException,
            IllegalLifeCycleException {
    }

    public void registerConnection(QName consInterface, QName provService, String provEndpoint) {
    }

    public void registerConnection(QName consService, String consEndpoint, QName provService,
            String provEndpoint) {
    }

    public void deregisterConnection(QName consInterface, QName provService, String provEndpoint) {
    }

    public void deregisterConnection(QName consService, String consEndpoint, QName provService,
            String provEndpoint) {
    }

    public ServiceEndpoint getEndpoint(QName service, String name, boolean resolveLink) {
        JBIServiceEndpointImpl ep = new JBIServiceEndpointImpl();
        ep.setServiceName(service);
        ep.setEndpointName(name);
        ep.getLocation().setComponentName("compo");
        ep.getLocation().setContainerName("0");
        ep.getLocation().setSubdomainName("subdomain");

        return ep;
    }

    public List<Map<String, Object>> getAllEndpoints() {
        return null;
    }

    public List<Map<String, Object>> getAllExternalEndpoints() {
        return null;
    }

    public List<Map<String, Object>> getAllInternalEndpoints() {
        return null;
    }

    public String getDescription(String serviceName, String endpointName) {
        return null;
    }

    public void updateNewEndpoints(boolean remoteContainerInvocation) throws JBIException {
        // TODO Auto-generated method stub

    }

    public org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint[] getInternalEndpointsForInterface(
            QName interfaceName, LinkType linktype) {
        // TODO Auto-generated method stub
        return null;
    }

    public org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint[] getInternalEndpointsForService(
            QName serviceName, LinkType linktype) {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint activateEndpoint(final QName serviceName,
            final String endpointName, final List<QName> interfaces, final Document description,
            final org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint address, final boolean canOverwrite) {
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public List<org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint> getEndpoints()
            throws RegistryException {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public List<org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint> getExternalEndpoints()
            throws RegistryException {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public List<org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint> getInternalEndpoints()
            throws RegistryException {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public void deactivateEndpoint(String endpointName, QName serviceName) throws RegistryException {
        // TODO Auto-generated method stub

    }

    /**
     * {@inheritDoc}
     */
    public void deregisterExternalEndpoint(String endpointName, QName serviceName)
            throws RegistryException {
        // TODO Auto-generated method stub

    }

    /**
     * {@inheritDoc}
     */
    public Document getEndpointDescriptorForEndpoint(
            org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint endpoint)
            throws RegistryException {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public QName[] getInterfacesForEndpoint(
            org.ow2.petals.microkernel.api.jbi.servicedesc.PetalsServiceEndpoint endpoint) {
        // TODO Auto-generated method stub
        return null;
    }

    /**
     * {@inheritDoc}
     */
    public void removeAllLocalEndpoints() throws RegistryException {
        // TODO Auto-generated method stub

    }

    /**
     * {@inheritDoc}
     */
    public List<RegistryListener> getListeners() {
        // TODO Auto-generated method stub
        return null;
    }

    @Override
    public boolean lockDynamicTopology() throws InterruptedException {
        return false;
    }

    @Override
    public void unlockDynamicTopology() throws DynamicTopologyNotLockedException,
            DynamicTopologyNotLockedByCurrentThreadException {
        // NOP
    }

    @Override
    public void setDynamicTopology(Topology topology) throws DynamicTopologyNotLockedException,
            DynamicTopologyNotLockedByCurrentThreadException {
        // NOP
    }

    @Override
    public Topology getDynamicTopology() {
        return null;
    }

    @Override
    public Properties getConfiguration(final String providedTopologyPassphrase) {
        return null;
    }

    @Override
    public Document getTopologyPartConfiguration(final Properties properties) throws MutableImplException {
        return null;
    }
}
